// Hello, World! application. Copyright (C) 1996-1998 Santa Fe Institute.
// This library is distributed without any warranty; without even the
// implied warranty of merchantability or fitness for a particular purpose.
// See file LICENSE for details and terms of copying.

#import <objectbase.h>
#import <simtoolsgui/GUISwarm.h>
#import "PplModelSwarm.h"

// Sample graphical interface swarm for models.
@interface PplObserverSwarm: GUISwarm 
{
  int displayFrequency;

  id displayActions;
  id displaySchedule;

  // add the modelswarm to the observer swarm
  PplModelSwarm* pplModelSwarm;
  // add the counter to the observer swarm
  Counter* observedCounter;
}

+ createBegin: aZone;
- createEnd;
- buildObjects;
- buildActions;
- activateIn: swarmContext;

@end
